@@ -17,7 +17,7 @@ import eventlet
 from oslo_log import log as logging
 from oslo_serialization import jsonutils
 from oslo_utils import netutils
-import retrying
+import tenacity
 
 from heat.common import exception
 from heat.common.i18n import _
@@ -359,20 +359,13 @@ class ServerNetworkMixin(object):
 
             # according to nova interface-detach command detached port
             # will be deleted
-            inter_port_data = self._data_get_ports()
-            inter_port_ids = [p['id'] for p in inter_port_data]
             for net in old_nets:
-                port_id = net.get(self.NETWORK_PORT)
-                # we can't match the port for some user case, like:
-                # the internal port was detached in nova first, then
-                # user update template to detach this nic. The internal
-                # port will remains till we delete the server resource.
-                if port_id:
-                    remove_ports.append(port_id)
-                    if port_id in inter_port_ids:
+                if net.get(self.NETWORK_PORT):
+                    remove_ports.append(net.get(self.NETWORK_PORT))
+                    if self.data().get('internal_ports'):
                         # if we have internal port with such id, remove it
                         # instantly.
-                        self._delete_internal_port(port_id)
+                        self._delete_internal_port(net.get(self.NETWORK_PORT))
                 if net.get(self.NETWORK_FLOATING_IP):
                     self._floating_ip_disassociate(
                         net.get(self.NETWORK_FLOATING_IP))
@@ -429,8 +422,12 @@ class ServerNetworkMixin(object):
     def detach_ports(self, server):
         existing_server_id = server.resource_id
         for port in self.get_all_ports(server):
-            self.client_plugin().interface_detach(
+            detach_called = self.client_plugin().interface_detach(
                 existing_server_id, port['id'])
+
+            if not detach_called:
+                return
+
             try:
                 if self.client_plugin().check_interface_detach(
                         existing_server_id, port['id']):
@@ -438,7 +435,7 @@ class ServerNetworkMixin(object):
                                  'server %(server)s.')
                              % {'port': port['id'],
                                 'server': existing_server_id})
-            except retrying.RetryError:
+            except tenacity.RetryError:
                 raise exception.InterfaceDetachFailed(
                     port=port['id'], server=existing_server_id)
 
@@ -455,7 +452,7 @@ class ServerNetworkMixin(object):
                                  'server %(server)s')
                              % {'port': port['id'],
                                 'server': prev_server_id})
-            except retrying.RetryError:
+            except tenacity.RetryError:
                 raise exception.InterfaceAttachFailed(
                     port=port['id'], server=prev_server_id)
 
@@ -480,7 +477,8 @@ class ServerNetworkMixin(object):
 
         # In case of convergence, during rollback, the previous rsrc is
         # already selected and is being acted upon.
-        backup_res = self.stack._backup_stack().resources.get(self.name)
+        backup_stack = self.stack._backup_stack()
+        backup_res = backup_stack.resources.get(self.name)
         prev_server = self if convergence else backup_res
 
         if convergence:
