@@ -20,7 +20,6 @@ import itertools
 import re
 import warnings
 
-from keystoneauth1 import exceptions as ks_exceptions
 from oslo_config import cfg
 from oslo_log import log as logging
 from oslo_utils import encodeutils
@@ -1261,7 +1260,7 @@ class Stack(collections.Mapping):
 
         # TODO(later): lifecycle_plugin_utils.do_pre_ops
 
-        self._converge_create_or_update()
+        self.thread_group_mgr.start(self.id, self._converge_create_or_update)
 
     def _converge_create_or_update(self):
         current_resources = self._update_or_store_resources()
@@ -1315,6 +1314,8 @@ class Stack(collections.Mapping):
                                                   self.current_traversal,
                                                   input_data, is_update,
                                                   self.adopt_stack_data)
+                if scheduler.ENABLE_SLEEP:
+                    eventlet.sleep(1)
 
     def rollback(self):
         old_tmpl_id = self.prev_raw_template_id
@@ -1694,11 +1695,6 @@ class Stack(collections.Mapping):
                         else:
                             self.clients.client('keystone').delete_trust(
                                 trust_id)
-                    except ks_exceptions.Unauthorized:
-                        # ignore if unauthorized, don't to set FAILED
-                        LOG.warning(_LW("Unauthorized, including the cases: "
-                                        "the trustor is deleted or the trust "
-                                        "is expired."))
                     except Exception as ex:
                         LOG.exception(_LE("Error deleting trust"))
                         stack_status = self.FAILED
